# GeoDSKit

A modern comprehensive geographic datasets handler kit.

![kfRdDh](https://songshgeo-picgo-1302043007.cos.ap-beijing.myqcloud.com/uPic/kfRdDh.png)

## Features

- [ ] Search and automatically download [NOAA](https://www.ncei.noaa.gov/) datasets.
- [ ] Handle local CMIP6 datasets with standard naming convention in batch.
- [x] NetCDF4 file handler.
- [x] Find and filter geospatial dataset files.

## Installation

```bash
pip install geo-dskit
```
